@@ -6,9 +6,8 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 
-from ovirt_imageio_common import web
-
 from . import version
+from . import web
 from . http_helper import addcors
 
 
